about summary refs log tree commit diff
path: root/pkgs/applications/misc/eaglemode
diff options
context:
space:
mode:
authorYurii Rashkovskii <yrashk@gmail.com>2019-01-02 00:46:51 +0700
committerYurii Rashkovskii <yrashk@gmail.com>2019-01-02 00:46:51 +0700
commitce4d1da8bf03fb298f8b1932c0b5447ad7f6a158 (patch)
tree57c5a7f6e341d54aaa87dffdb516f00f1bfd7059 /pkgs/applications/misc/eaglemode
parent559916f6480b0cd745e52970dd1167ce7abbc6b1 (diff)
eaglemode: 0.86.0 -> 0.94.0
The build is no longer breaking so this derivation is no longer marked
broken.
Diffstat (limited to 'pkgs/applications/misc/eaglemode')
-rw-r--r--pkgs/applications/misc/eaglemode/default.nix24
1 files changed, 12 insertions, 12 deletions
diff --git a/pkgs/applications/misc/eaglemode/default.nix b/pkgs/applications/misc/eaglemode/default.nix
index 0404ef8ce2201..255396a795023 100644
--- a/pkgs/applications/misc/eaglemode/default.nix
+++ b/pkgs/applications/misc/eaglemode/default.nix
@@ -1,35 +1,36 @@
-{ stdenv, fetchurl, perl, libX11, libjpeg, libpng, libtiff, pkgconfig,
-librsvg, glib, gtk2, libXext, libXxf86vm, poppler, xineLib }:
+{ stdenv, fetchurl, perl, libX11, libXinerama, libjpeg, libpng, libtiff, pkgconfig,
+librsvg, glib, gtk2, libXext, libXxf86vm, poppler, xineLib, ghostscript, makeWrapper }:
 
 stdenv.mkDerivation rec {
-  name = "eaglemode-0.86.0";
+  name = "eaglemode-${version}";
+  version = "0.94.0";
 
   src = fetchurl {
     url = "mirror://sourceforge/eaglemode/${name}.tar.bz2";
-    sha256 = "1a2hzyck95g740qg4p4wd4fjwsmlknh75i9sbx5r5v9pyr4i3m4f";
+    sha256 = "1sr3bd9y9j2svqvdwhrak29yy9cxf92w9vq2cim7a8hzwi9qfy9k";
   };
 
   nativeBuildInputs = [ pkgconfig ];
-  buildInputs = [ perl libX11 libjpeg libpng libtiff
-    librsvg glib gtk2 libXxf86vm libXext poppler xineLib ];
+  buildInputs = [ perl libX11 libXinerama libjpeg libpng libtiff
+    librsvg glib gtk2 libXxf86vm libXext poppler xineLib ghostscript makeWrapper ];
 
   # The program tries to dlopen both Xxf86vm and Xext, so we use the
   # trick on NIX_LDFLAGS and dontPatchELF to make it find them.
   # I use 'yes y' to skip a build error linking with xineLib,
   # because xine stopped exporting "_x_vo_new_port"
   #  https://sourceforge.net/projects/eaglemode/forums/forum/808824/topic/5115261
   buildPhase = ''
-    export NIX_LDFLAGS="$NIX_LDFLAGS -lXxf86vm -lXext"
+    export NIX_LDFLAGS="$NIX_LDFLAGS -lXxf86vm -lXext -lXinerama"
     perl make.pl build
   '';
 
   dontPatchELF = true;
+  # eaglemode expects doc to be in the root directory
+  forceShare = [ "man" "info" ];
 
   installPhase = ''
     perl make.pl install dir=$out
-    # I don't like this... but it seems the way they plan to run it by now.
-    # Run 'eaglemode.sh', not 'eaglemode'.
-    ln -s $out/eaglemode.sh $out/bin/eaglemode.sh
+    wrapProgram $out/bin/eaglemode --set EM_DIR "$out" --prefix LD_LIBRARY_PATH : "$out/lib" --prefix PATH : "${ghostscript}/bin"
   '';
 
   meta = with stdenv.lib; {
@@ -38,6 +39,5 @@ stdenv.mkDerivation rec {
     license = licenses.gpl3;
     maintainers = with maintainers; [ ];
     platforms = platforms.linux;
-    broken = true;
   };
 }
@@ -1,35 +1,36 @@
 
-  # The program tries to dlopen both Xxf86vm and Xext, so we use the
+  # The program tries to dlopen Xxf86vm, Xext and Xinerama, so we use the
   # trick on NIX_LDFLAGS and dontPatchELF to make it find them.
   # I use 'yes y' to skip a build error linking with xineLib,